@@ -26,3 +26,8 @@ def convert_floats(input_data: Dict[str, Any], keys: List[str], default_value=No
 
 def is_zero(an_input: float) -> bool:
     return math.isclose(an_input, 0.0)
+
+
+def readable_float_to_str(an_input: float, decimal_points: int = 20) -> str:
+    format_str: str = '{:.' + str(decimal_points) + "f}"
+    return format_str.format(an_input)
